---
name: Bug report
about: Create a report to help us improve
---

<!--

Have you read wall's Code of Conduct? By filing an Issue, you are
expected to comply with it, including treating everyone with respect:
https://github.com/???/wall/blob/master/CODE_OF_CONDUCT.md

-->

## Describe the bug

_A clear and concise description of what the bug is._

## To Reproduce
Steps to reproduce the behavior:
1. <!-- First Step -->
2. <!-- Second Step -->
3. <!-- and so on… -->

**Expected behavior:**

_A clear and concise description of what you expected to happen._

**Actual behavior:**

_What actually happens._

**Reproduces how often:**

_What percentage of the time does it reproduce?_

## Platform (please complete the following information)
 - OS: _[e.g. Ubuntu 18.04, Windows 10 2004]_
 - Compiler: _[e.g. gcc-10, clang-10, msvc 16.4]_
 - Library version: _[e.g. tag name, commit id]_

## Additional information
_Any additional information, configuration or data that might be necessary to reproduce the issue._
